@@ -27,7 +27,7 @@ betatree <- function(formula, partition, data, subset = NULL, na.action = na.omi
   ))
   ## call for beta regression
   br_call <- match.call(expand.dots = FALSE)
-  br_call$partition <- br_call$cluster <- br_call[["..."]] <- NULL
+  br_call$partition <- br_call$cluster <- br_call$`...` <- NULL
   br_call$formula <- formula(formula, lhs = 1L, rhs = 1L:2L)
   
   ## terms
@@ -73,7 +73,7 @@ betatree <- function(formula, partition, data, subset = NULL, na.action = na.omi
     if(estfun | object) {
       class(obj) <- "betareg"
       obj$contrasts <- attr(x, "contrasts")
-      obj$xlevels <- attr(x, "xlevels")    
+      obj$levels <- list(mu = attr(x, "xlevels"), phi = attr(x, "xlevels"), full = attr(x, "xlevels"))
       obj$call <- br_call
       obj$terms <- list(mean = xt, precision = zt, full = ft)
       obj$model <- mf
